@@ -18,12 +18,6 @@ pub enum DefaultAction {
     ReplacePane,
 }
 
-#[derive(Debug, Copy, Default, Clone, Deserialize, Serialize)]
-pub struct Config {
-    #[serde(default)]
-    pub sidebar_default_action: DefaultAction,
-}
-
 impl Dashboard {
     pub fn load() -> Result<Self, Error> {
         let path = path()?;
@@ -45,15 +39,13 @@ impl Dashboard {
 }
 
 fn path() -> Result<PathBuf, Error> {
-    let data_dir = environment::data_dir();
-
-    let parent = data_dir.join("halloy");
+    let parent = environment::data_dir();
 
     if !parent.exists() {
         std::fs::create_dir_all(&parent)?;
     }
 
-    Ok(parent.join("dashboard"))
+    Ok(parent.join("dashboard.json.gz"))
 }
 
 #[derive(Debug, thiserror::Error)]
