@@ -7,9 +7,10 @@ pub use self::dashboard::Dashboard;
 pub use self::input::Input;
 pub use self::message::Message;
 pub use self::mode::Mode;
-pub use self::palette::Palette;
 pub use self::pane::Pane;
 pub use self::server::Server;
+pub use self::shortcut::Shortcut;
+pub use self::theme::Theme;
 pub use self::user::User;
 
 pub mod buffer;
@@ -25,9 +26,10 @@ pub mod input;
 pub mod log;
 pub mod message;
 pub mod mode;
-pub mod palette;
 pub mod pane;
 pub mod server;
+pub mod shortcut;
 pub mod stream;
+pub mod theme;
 pub mod time;
 pub mod user;
