@@ -1,5 +1,5 @@
 pub use data::buffer::Settings;
-use data::{buffer, history, Config};
+use data::{buffer, history, Config, User};
 use iced::Command;
 
 use self::channel::Channel;
@@ -159,6 +159,20 @@ impl Buffer {
         }
     }
 
+    pub fn insert_user_to_input(&mut self, user: User) -> Command<Message> {
+        match self {
+            Buffer::Empty | Buffer::Server(_) => Command::none(),
+            Buffer::Channel(channel) => channel
+                .input_view
+                .insert_user(user)
+                .map(|message| Message::Channel(channel::Message::InputView(message))),
+            Buffer::Query(query) => query
+                .input_view
+                .insert_user(user)
+                .map(|message| Message::Query(query::Message::InputView(message))),
+        }
+    }
+
     pub fn scroll_to_start(&mut self) -> Command<Message> {
         match self {
             Buffer::Empty => Command::none(),
