@@ -50,6 +50,7 @@ pub fn view<'a>(
                             selectable_text(config.buffer.nickname.brackets.format(user)).style(
                                 theme::Text::Nickname(
                                     user.color_seed(&config.buffer.nickname.color),
+                                    false,
                                 ),
                             ),
                             user.clone(),
@@ -67,12 +68,20 @@ pub fn view<'a>(
                             }
                             _ => theme::Container::Default,
                         };
+
+                        let space = selectable_text(" ");
                         let message = selectable_text(&message.text);
 
                         Some(
-                            container(row![].push_maybe(timestamp).push(nick).push(message))
-                                .style(row_style)
-                                .into(),
+                            container(
+                                row![]
+                                    .push_maybe(timestamp)
+                                    .push(nick)
+                                    .push(space)
+                                    .push(message),
+                            )
+                            .style(row_style)
+                            .into(),
                         )
                     }
                     message::Source::Server(_) => {
@@ -101,7 +110,7 @@ pub fn view<'a>(
 
     let users = clients.get_channel_users(&state.server, &state.channel);
     let channels = clients.get_channels(&state.server);
-    let nick_list = nick_list::view(users).map(Message::UserContext);
+    let nick_list = nick_list::view(users, config).map(Message::UserContext);
 
     let show_text_input = match config.buffer.input_visibility {
         data::buffer::InputVisibility::Focused => is_focused && status.connected(),
@@ -218,7 +227,7 @@ impl Channel {
 }
 
 mod nick_list {
-    use data::User;
+    use data::{Config, User};
     use iced::widget::{column, container, scrollable, text};
     use iced::Length;
     use user_context::Message;
@@ -227,18 +236,17 @@ mod nick_list {
     use crate::theme;
     use crate::widget::Element;
 
-    pub fn view(users: &[User]) -> Element<Message> {
+    pub fn view<'a>(users: &[User], config: &'a Config) -> Element<'a, Message> {
         let column = column(users.iter().map(|user| {
             let content = text(format!(
                 "{}{}",
                 user.highest_access_level(),
                 user.nickname()
             ))
-            .style(if user.is_away() {
-                theme::Text::Transparent
-            } else {
-                theme::Text::Primary
-            });
+            .style(theme::Text::Nickname(
+                user.color_seed(&config.buffer.channel.users.color),
+                user.is_away(),
+            ));
 
             user_context::view(content, user.clone())
         }))
