@@ -8,7 +8,7 @@ use data::history::manager::Broadcast;
 use data::user::Nick;
 use data::{client, history, server, Config, Server, User};
 use iced::widget::pane_grid::{self, PaneGrid};
-use iced::widget::{container, row, Space};
+use iced::widget::{column, container, row, Space};
 use iced::{clipboard, window, Command, Length};
 
 use self::command_bar::CommandBar;
@@ -64,7 +64,11 @@ impl Dashboard {
     pub fn restore(dashboard: data::Dashboard) -> (Self, Command<Message>) {
         let mut dashboard = Dashboard::from(dashboard);
 
-        let command = dashboard.track();
+        let command = if let Some((pane, _)) = dashboard.panes.panes.iter().next() {
+            Command::batch(vec![dashboard.focus_pane(*pane), dashboard.track()])
+        } else {
+            dashboard.track()
+        };
 
         (dashboard, command)
     }
@@ -83,11 +87,11 @@ impl Dashboard {
                     return self.focus_pane(pane);
                 }
                 pane::Message::PaneResized(pane_grid::ResizeEvent { split, ratio }) => {
-                    self.panes.resize(&split, ratio);
+                    self.panes.resize(split, ratio);
                     self.last_changed = Some(Instant::now());
                 }
                 pane::Message::PaneDragged(pane_grid::DragEvent::Dropped { pane, target }) => {
-                    self.panes.drop(&pane, target);
+                    self.panes.drop(pane, target);
                     self.last_changed = Some(Instant::now());
                 }
                 pane::Message::PaneDragged(_) => {}
@@ -100,7 +104,7 @@ impl Dashboard {
                     return self.split_pane(axis, config);
                 }
                 pane::Message::Buffer(id, message) => {
-                    if let Some(pane) = self.panes.get_mut(&id) {
+                    if let Some(pane) = self.panes.get_mut(id) {
                         let (command, event) =
                             pane.buffer.update(message, clients, &mut self.history);
 
@@ -168,7 +172,7 @@ impl Dashboard {
                         return self.open_buffer(kind, config);
                     }
                     side_menu::Event::Replace(kind, pane) => {
-                        if let Some(state) = self.panes.get_mut(&pane) {
+                        if let Some(state) = self.panes.get_mut(pane) {
                             state.buffer = Buffer::from(kind);
                             self.last_changed = Some(Instant::now());
                             self.focus = None;
@@ -179,7 +183,7 @@ impl Dashboard {
                         }
                     }
                     side_menu::Event::Close(pane) => {
-                        self.panes.close(&pane);
+                        self.panes.close(pane);
                         self.last_changed = Some(Instant::now());
 
                         if self.focus == Some(pane) {
@@ -187,7 +191,7 @@ impl Dashboard {
                         }
                     }
                     side_menu::Event::Swap(from, to) => {
-                        self.panes.swap(&from, &to);
+                        self.panes.swap(from, to);
                         self.last_changed = Some(Instant::now());
                         return self.focus_pane(from);
                     }
@@ -198,8 +202,8 @@ impl Dashboard {
 
                         // Close pane
                         if let Some(pane) = pane {
-                            if self.panes.close(&pane).is_none() {
-                                if let Some(state) = self.panes.get_mut(&pane) {
+                            if self.panes.close(pane).is_none() {
+                                if let Some(state) = self.panes.get_mut(pane) {
                                     state.buffer = Buffer::Empty;
                                 }
                             }
@@ -290,7 +294,7 @@ impl Dashboard {
                 self.history.update(message);
             }
             Message::Close => {
-                return window::close();
+                return window::close(window::Id::MAIN);
             }
             Message::DashboardSaved(Ok(_)) => {
                 log::info!("dashboard saved");
@@ -331,7 +335,7 @@ impl Dashboard {
                                     let mut commands = vec![];
 
                                     if let Some(pane) = self.focus.take() {
-                                        if let Some(state) = self.panes.get_mut(&pane) {
+                                        if let Some(state) = self.panes.get_mut(pane) {
                                             state.buffer = Buffer::from(buffer);
                                             self.last_changed = Some(Instant::now());
 
@@ -385,7 +389,7 @@ impl Dashboard {
 
                 let mut move_focus = |direction: pane_grid::Direction| {
                     if let Some(pane) = self.focus.as_ref() {
-                        if let Some(adjacent) = self.panes.adjacent(pane, direction) {
+                        if let Some(adjacent) = self.panes.adjacent(*pane, direction) {
                             return self.focus_pane(adjacent);
                         }
                     } else if let Some((pane, _)) = self.panes.panes.iter().next() {
@@ -407,7 +411,7 @@ impl Dashboard {
                     }
                     MaximizeBuffer => {
                         if let Some(pane) = self.focus.as_ref() {
-                            self.panes.maximize(pane);
+                            self.panes.maximize(*pane);
                         }
                     }
                     RestoreBuffer => {
@@ -452,6 +456,13 @@ impl Dashboard {
                             });
                         }
                     }
+                    CommandBar => {
+                        return self.toggle_command_bar(
+                            &closed_buffers(self, clients),
+                            config,
+                            theme,
+                        );
+                    }
                 }
             }
         }
@@ -539,7 +550,10 @@ impl Dashboard {
                 10.0,
             )
         } else {
-            base.into()
+            // Align `base` into same view tree shape
+            // as `anchored_overlay` to prevent diff
+            // from firing when displaying command bar
+            column![column![base]].into()
         };
 
         shortcut(base, config.keys.shortcuts(), Message::Shortcut)
@@ -611,7 +625,6 @@ impl Dashboard {
 
                 Command::perform(task, |_| Message::Close)
             }
-            CommandBar => self.toggle_command_bar(&closed_buffers(self, clients), config, theme),
         }
     }
 
@@ -657,7 +670,7 @@ impl Dashboard {
 
         let result = self
             .panes
-            .split(axis, &pane_to_split, Pane::new(Buffer::from(kind), config));
+            .split(axis, pane_to_split, Pane::new(Buffer::from(kind), config));
         self.last_changed = Some(Instant::now());
 
         if let Some((pane, _)) = result {
@@ -677,6 +690,7 @@ impl Dashboard {
         user: User,
         comment: Option<String>,
         user_channels: Vec<String>,
+        config: &Config,
     ) {
         self.history.broadcast(
             server,
@@ -685,6 +699,7 @@ impl Dashboard {
                 comment,
                 user_channels,
             },
+            config,
         );
     }
 
@@ -695,6 +710,7 @@ impl Dashboard {
         new_nick: Nick,
         ourself: bool,
         user_channels: Vec<String>,
+        config: &Config,
     ) {
         self.history.broadcast(
             server,
@@ -704,6 +720,7 @@ impl Dashboard {
                 ourself,
                 user_channels,
             },
+            config,
         );
     }
 
@@ -713,6 +730,7 @@ impl Dashboard {
         inviter: Nick,
         channel: String,
         user_channels: Vec<String>,
+        config: &Config,
     ) {
         self.history.broadcast(
             server,
@@ -721,34 +739,42 @@ impl Dashboard {
                 channel,
                 user_channels,
             },
+            config,
         );
     }
 
-    pub fn broadcast_connecting(&mut self, server: &Server) {
-        self.history.broadcast(server, Broadcast::Connecting);
-    }
-
-    pub fn broadcast_connected(&mut self, server: &Server) {
-        self.history.broadcast(server, Broadcast::Connected);
-    }
-
-    pub fn broadcast_disconnected(&mut self, server: &Server, error: Option<String>) {
+    pub fn broadcast_connecting(&mut self, server: &Server, config: &Config) {
         self.history
-            .broadcast(server, Broadcast::Disconnected { error });
+            .broadcast(server, Broadcast::Connecting, config);
     }
 
-    pub fn broadcast_reconnected(&mut self, server: &Server) {
-        self.history.broadcast(server, Broadcast::Reconnected);
+    pub fn broadcast_connected(&mut self, server: &Server, config: &Config) {
+        self.history.broadcast(server, Broadcast::Connected, config);
     }
 
-    pub fn broadcast_connection_failed(&mut self, server: &Server, error: String) {
+    pub fn broadcast_disconnected(
+        &mut self,
+        server: &Server,
+        error: Option<String>,
+        config: &Config,
+    ) {
         self.history
-            .broadcast(server, Broadcast::ConnectionFailed { error });
+            .broadcast(server, Broadcast::Disconnected { error }, config);
+    }
+
+    pub fn broadcast_reconnected(&mut self, server: &Server, config: &Config) {
+        self.history
+            .broadcast(server, Broadcast::Reconnected, config);
+    }
+
+    pub fn broadcast_connection_failed(&mut self, server: &Server, error: String, config: &Config) {
+        self.history
+            .broadcast(server, Broadcast::ConnectionFailed { error }, config);
     }
 
     fn get_focused_mut(&mut self) -> Option<(pane_grid::Pane, &mut Pane)> {
         let pane = self.focus?;
-        self.panes.get_mut(&pane).map(|state| (pane, state))
+        self.panes.get_mut(pane).map(|state| (pane, state))
     }
 
     fn focus_pane(&mut self, pane: pane_grid::Pane) -> Command<Message> {
@@ -775,7 +801,7 @@ impl Dashboard {
         if self.is_pane_maximized() {
             self.panes.restore();
         } else if let Some(pane) = self.focus {
-            self.panes.maximize(&pane);
+            self.panes.maximize(pane);
         }
     }
 
@@ -794,7 +820,7 @@ impl Dashboard {
             if let Some(pane) = pane {
                 let result = self
                     .panes
-                    .split(axis, &pane, Pane::new(Buffer::Empty, config));
+                    .split(axis, pane, Pane::new(Buffer::Empty, config));
                 self.last_changed = Some(Instant::now());
 
                 if let Some((pane, _)) = result {
@@ -815,7 +841,7 @@ impl Dashboard {
         if let Some(pane) = self.focus {
             let result = self
                 .panes
-                .split(axis, &pane, Pane::new(Buffer::Empty, config));
+                .split(axis, pane, Pane::new(Buffer::Empty, config));
             self.last_changed = Some(Instant::now());
             if let Some((pane, _)) = result {
                 return self.focus_pane(pane);
@@ -842,9 +868,9 @@ impl Dashboard {
     fn close_pane(&mut self, pane: pane_grid::Pane) -> Command<Message> {
         self.last_changed = Some(Instant::now());
 
-        if let Some((_, sibling)) = self.panes.close(&pane) {
+        if let Some((_, sibling)) = self.panes.close(pane) {
             return self.focus_pane(sibling);
-        } else if let Some(pane) = self.panes.get_mut(&pane) {
+        } else if let Some(pane) = self.panes.get_mut(pane) {
             pane.buffer = Buffer::Empty;
         }
 
@@ -988,7 +1014,7 @@ impl<'a> From<&'a Dashboard> for data::Dashboard {
                     b: Box::new(from_layout(panes, *b)),
                 },
                 Node::Pane(pane) => panes
-                    .get(&pane)
+                    .get(pane)
                     .cloned()
                     .map(data::Pane::from)
                     .unwrap_or(data::Pane::Empty),
